from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Sensor_Touch = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AT42QT1010-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1010-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001946A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1010-M\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='SNSK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SNS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1010-TSHR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1010-TSHR'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001946A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1010-TSHR\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SNSK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SNS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SYNC',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1012-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1012-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001948A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1012-M\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='SNSK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='TIME',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SNS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1012-T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1012-T'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001948A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1012-T\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SNSK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SNS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='TIME',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1040-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1040-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-9524-AT42-QTouch-BSW-AT42QT1040_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1040-M\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='SNS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='~{OUT0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{OUT1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{OUT3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{OUT2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='SNSK3',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='SNS3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='SNSK1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='SNSK2',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SNS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SNSK0',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SNS0',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1050-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1050-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-9707-AT42-QTouch-BSW-AT42QT1050_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1050-M\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='KEY2',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='ADDR_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{CHANGE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='KEY4',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='KEY3',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='KEY1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='KEY0',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1050-U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1050-U'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-12_1.403x1.555mm_P0.4mm_Stagger'], 'footprint':'Package_CSP:WLCSP-12_1.403x1.555mm_P0.4mm_Stagger', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-9707-AT42-QTouch-BSW-AT42QT1050_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1050-U\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='A1',name='KEY2',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='KEY0',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='KEY1',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='KEY4',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='KEY3',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='~{CHANGE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='D4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='ADDR_SEL',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1060-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1060-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:VQFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-9505-AT42-QTouch-BSW-AT42QT1060_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1060-M\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='SNS1K',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SNS0',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SNS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SNS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='SNS3',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SNS4',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='SNS5',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SNS2K',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='~{CHG}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SNS0K',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SNS3K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SNS4K',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='SNS5K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1070-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1070-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-9596-AT42-QTouch-BSW-AT42QT1070_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1070-M\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='KEY4',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SDA/OUT0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{CHANGE}/OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='SCL/OUT3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='OUT2/KEY6',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUT1/KEY5',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='KEY3',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='KEY2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='KEY1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='KEY0',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1070-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1070-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-9596-AT42-QTouch-BSW-AT42QT1070_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1070-S\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='KEY3',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='KEY2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='KEY1',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='KEY0',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDA/OUT0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{CHANGE}/OUT4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SCL/OUT3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='OUT2/KEY6',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT1/KEY5',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='KEY4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1110-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1110-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:VQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-9520-AT42-QTouch-BSW-AT42QT1110_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1110-M\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='SNS0K',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SNS4',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SNS4K',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SNS5',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='SNS5K',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~{SS}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SNS6K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SNS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='SNS6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='DETECT0/SNS7K',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DETECT1/SNS7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='DETECT2/SNS8',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='DETECT3/SNS8K',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='DETECT4/SNS9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DETECT5/SNS9K',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='~{CHANGE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='29',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SNS1K',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='DETECT6/SNS10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='SYNC/SNS10K',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='SNS0',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SNS2K',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SNS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SNS3',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='SNS3K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CAP1206-x-AIA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CAP1206-x-AIA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.55x2.48mm'], 'footprint':'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.55x2.48mm', 'keywords':'6 Channel Capacitive Touch Sensor', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/00001567B.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nCAP1206-x-AIA\n\n6 Channel Capacitive Touch Sensor', 'pins':[
            Pin(num='1',name='CS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ALERT#',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='SMDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CS6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CS5',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='CS4',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CS3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CAP1206-x-SL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CAP1206-x-SL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'6 Channel Capacitive Touch Sensor', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/00001567B.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nCAP1206-x-SL\n\n6 Channel Capacitive Touch Sensor', 'pins':[
            Pin(num='10',name='CS5',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CS4',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CS3',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='ALERT#',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='SMDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CS6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8CMBR3002', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8CMBR3002'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Touch Sensor 2ch', 'description':'', 'datasheet':'http://www.cypress.com/?docID=49119', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nCY8CMBR3002\n\nTouch Sensor 2ch', 'pins':[
            Pin(num='1',name='GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CMOD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CS0',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GPO0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8CMBR3102', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8CMBR3102'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Touch Sensor 2ch', 'description':'', 'datasheet':'http://www.cypress.com/?docID=49119', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nCY8CMBR3102\n\nTouch Sensor 2ch', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CMOD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CS0',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8CMBR3106S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8CMBR3106S'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Touch Sensor 16ch Slider', 'description':'', 'datasheet':'http://www.cypress.com/?docID=49119', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nCY8CMBR3106S\n\nTouch Sensor 16ch Slider', 'pins':[
            Pin(num='1',name='CS0',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SLD11',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SLD12',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SLD13',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='SLD14',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='CS11',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='CS12',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='CS13',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='CS14',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='CS15',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='CS5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='CS4',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{HI}',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{XRES}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CS3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CMOD',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SLD10',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8CMBR3108', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8CMBR3108'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm', 'keywords':'Touch Sensor 8ch', 'description':'', 'datasheet':'http://www.cypress.com/?docID=49119', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nCY8CMBR3108\n\nTouch Sensor 8ch', 'pins':[
            Pin(num='1',name='CS0',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CS6',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CS7',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CS3',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{HI}',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CMOD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CS4',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CS5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8CMBR3110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8CMBR3110'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'Touch Sensor 10ch', 'description':'', 'datasheet':'http://www.cypress.com/?docID=49119', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nCY8CMBR3110\n\nTouch Sensor 10ch', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CS6',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CS7',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CS8',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='CS9',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='CS3',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='CS4',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CS0',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CMOD',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CS5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY8CMBR3116', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY8CMBR3116'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Touch Sensor 16ch', 'description':'', 'datasheet':'http://www.cypress.com/?docID=49119', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nCY8CMBR3116\n\nTouch Sensor 16ch', 'pins':[
            Pin(num='1',name='CS0',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CS14',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CS13',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CS12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CS11',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='CS10',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='CS9',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='CS8',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='CS7',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='CS6',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='CS5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='CS4',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{HI}',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{XRES}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CS3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CMOD',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CS15',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MPR121QR2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MPR121QR2'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-20_3x3mm_P0.4mm'], 'footprint':'Package_DFN_QFN:UQFN-20_3x3mm_P0.4mm', 'keywords':'Touch Sensor 12ch', 'description':'', 'datasheet':'https://resurgentsemi.com/wp-content/uploads/2018/09/MPR121_rev5-Resurgent.pdf?d453f8&d453f8', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nMPR121QR2\n\nTouch Sensor 12ch', 'pins':[
            Pin(num='1',name='~{IRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='ELE2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='ELE3',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='LED0/ELE4',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LED1/ELE5',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LED2/ELE6',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LED3/ELE7',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='LED4/ELE8',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='LED5/ELE9',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='LED6/ELE10',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='LED7/ELE11',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VREG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='REXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='ELE0',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='ELE1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA8886', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA8886'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP capacitive touch sensor auto-calibration', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCA8886.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nPCA8886\n\nNXP capacitive touch sensor auto-calibration', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='CLIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD(int)1',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='TYPE1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CPC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT2',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='CLIN2',func=pin_types.BIDIR,unit=2),
            Pin(num='12',name='VDD(int)2',func=pin_types.PWROUT,unit=2),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='TYPE2',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='CPC2',func=pin_types.BIDIR,unit=2),
            Pin(num='8',name='VSS2',func=pin_types.PWRIN,unit=2),
            Pin(num='9',name='VDD2',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '16', '14', '4', '13', '2', '15', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '12', '6', '10', '8', '11', '9']}] }),
        Part(**{ 'name':'PCF8883', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCF8883'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'NXP capacitive touch sensor auto-calibration', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/PCF8883.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nPCF8883\n\nNXP capacitive touch sensor auto-calibration', 'pins':[
            Pin(num='1',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TYPE',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CPC',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='CLIN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD(int)',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1011-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1011-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001947A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1011-M\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='SNSK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SNS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT42QT1011-TSHR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT42QT1011-TSHR'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Touch QTouch Sensor Key', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001947A.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Touch.kicad_sym\nAT42QT1011-TSHR\n\nTouch QTouch Sensor Key', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SNSK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SNS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SYNC',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])